class APIVersion:
    V1 = "v1"
    V2 = "v2"


class FipeTipoVeiculo:
    CAMINHOES = "caminhoes"
    CARROS = "carros"
    MOTOS = "motos"


class IBGEProvider:
    DADOS_ABERTOS_BR = "dados-abertos-br"
    GOV = "gov"
    WIKIPEDIA = "wikipedia"


class TaxaJurosType:
    SELIC = "selic"
    CDI = "cdi"
    IPCA = "ipca"
